@@ -1,4 +1,4 @@
-// Copyright (c) Jeremy Tuloup
+// Copyright (c) ipylab contributors
 // Distributed under the terms of the Modified BSD License.
 
 import {
@@ -36,6 +36,8 @@ const extension: JupyterFrontEndPlugin<void> = {
     widgetExports.ShellModel.shell = shell;
     widgetExports.CommandRegistryModel.commands = app.commands;
     widgetExports.CommandPaletteModel.palette = palette;
+    widgetExports.SessionManagerModel.sessions = app.serviceManager.sessions;
+    widgetExports.SessionManagerModel.shell = shell;
 
     registry.registerWidget({
       name: MODULE_NAME,
