@@ -1,11 +1,9 @@
-// Copyright (c) Jeremy Tuloup
+// Copyright (c) ipylab contributors
 // Distributed under the terms of the Modified BSD License.
 
-// Import the CSS
-import '../css/widget.css';
-
 import { CommandRegistryModel } from './widgets/commands';
 import { CommandPaletteModel } from './widgets/palette';
+import { SessionManagerModel } from './widgets/sessions';
 import { JupyterFrontEndModel } from './widgets/frontend';
 import { PanelModel } from './widgets/panel';
 import { ShellModel } from './widgets/shell';
@@ -21,4 +19,5 @@ export {
   SplitPanelModel,
   SplitPanelView,
   TitleModel,
+  SessionManagerModel,
 };
